Default method to print the results from a call to cgaim.
Conveniently prints the formula, beta and alpha coefficients
as well as the residual sum of squares.
Usage
# S3 method for cgaim
print(x, ...)
Value
Function called for its side effect of printing a cgaim object. Returns no value.
Arguments
x
A cgaim object.
...
For compatibility with the default print method. Unused
at the moment.